==> root_v5.02.00.source.tar.gz: root/alien/inc/TAlienJob.h <==
// @(#)root/alien:$Name:  $:$Id: TAlienJob.h,v 1.1 2005/05/20 11:13:30 rdm Exp $
// Author: Jan Fiete Grosse-Oetringhaus  06/10/2004

/*************************************************************************
 * Copyright (C) 1995-2004, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#ifndef ROOT_TAlienJob
#define ROOT_TAlienJob

//////////////////////////////////////////////////////////////////////////
//                                                                      //
// TAlienJob                                                            //
//                                                                      //
// Alien implentation of TGridJob                                       //
//                                                                      //
// Related classes are TAlienJobStatus.                                 //
//                                                                      //
//////////////////////////////////////////////////////////////////////////

#ifndef ROOT_TGridJob
#include "TGridJob.h"
#endif


class TAlienJob : public TGridJob {

public:
   TAlienJob(GridJobID_t jobID) : TGridJob(jobID) { }
   virtual ~TAlienJob() { }

   virtual TGridJobStatus *GetJobStatus() const;

   ClassDef(TAlienJob,1)  // Alien implementation of TGridJob
};

#endif

==> root_v5.16.00.source.tar.gz: root/alien/inc/TAlienJob.h <==
// @(#)root/alien:$Name:  $:$Id: TAlienJob.h,v 1.2 2007/05/11 14:23:33 rdm Exp $
// Author: Jan Fiete Grosse-Oetringhaus  06/10/2004

/*************************************************************************
 * Copyright (C) 1995-2004, Rene Brun and Fons Rademakers.               *
 * All rights reserved.                                                  *
 *                                                                       *
 * For the licensing terms see $ROOTSYS/LICENSE.                         *
 * For the list of contributors see $ROOTSYS/README/CREDITS.             *
 *************************************************************************/

#ifndef ROOT_TAlienJob
#define ROOT_TAlienJob

//////////////////////////////////////////////////////////////////////////
//                                                                      //
// TAlienJob                                                            //
//                                                                      //
// Alien implentation of TGridJob                                       //
//                                                                      //
// Related classes are TAlienJobStatus.                                 //
//                                                                      //
//////////////////////////////////////////////////////////////////////////

#ifndef ROOT_TGridJob
#include "TGridJob.h"
#endif


class TAlienJob : public TGridJob {

public:
   TAlienJob(TString jobID) : TGridJob(jobID) { }
   virtual ~TAlienJob() { }

   virtual TGridJobStatus *GetJobStatus() const;

   ClassDef(TAlienJob,1)  // Alien implementation of TGridJob
};

#endif
